==> fhir_auth-0.9.2.tar.gz: demos/webauthdemo/lib/new_patient.dart <==
import 'dart:math';

import 'package:fhir/r4.dart';

Patient newPatient() {
  final endDigits = digits(6).toString();
  final zNum = digits(4).toString();
  return Patient(
    identifier: [
      Identifier(
        type: CodeableConcept(
          coding: [
            Coding(
              system: FhirUri('http://terminology.hl7.org/CodeSystem/v2-0203'),
              code: Code('SS'),
            ),
          ],
        ),
        system: FhirUri('http://hl7.org/fhir/sid/us-ssn'),
        value: digits(9).toString(),
      ),
      Identifier.fromJson({
        "use": "usual",
        "type": {"text": "WPRINTERNAL"},
        "system": "urn:oid: 1.2.840.114350.1.13.0.1.7.2.${digits(6)}",
        "value": "${digits(3)}",
      }),
      Identifier.fromJson(
        {
          "use": "usual",
          "type": {"text": "EXTERNAL"},
          "system": "urn:oid: 1.2.840.114350.1.13.0.1.7.2.$endDigits",
          "value": "Z$zNum"
        },
      ),
      Identifier.fromJson(
        {
          "use": "usual",
          "type": {"text": "INTERNAL"},
          "system": "urn:oid: 1.2.840.114350.1.13.0.1.7.2.$endDigits",
          "value": "Z$zNum"
        },
      ),
    ],
    active: Boolean(true),
    name: [
      HumanName(
        family: lastNames[random(50)],
        given: [firstNames[random(200)]],
      ),
    ],
    address: [Address(postalCode: zipCode())],
    gender: random(10) < 5 ? Code('male') : Code('female'),
    birthDate: Date(
        '${1900 + random(120)}-0${random(8) + 1}-${(random(27) + 1).toString().padLeft(2, '0')}'),
  );
}

int random(int numb) {
  final _rand = Random();
  return _rand.nextInt(numb);
}

String zipCode() => digits(5);

String digits(int digit) {
  const _chars = '1234567890';
  final _rnd = Random();
  return String.fromCharCodes(Iterable.generate(
      digit, (_) => _chars.codeUnitAt(_rnd.nextInt(_chars.length))));
}

const lastNames = [
  'Smith',
  'Johnson',
  'Williams',
  'Brown',
  'Jones',
  'Garcia',
  'Miller',
  'Davis',
  'Rodriguez',
  'Martinez',
  'Hernandez',
  'Lopez',
  'Gonzalez',
  'Wilson',
  'Anderson',
  'Thomas',
  'Taylor',
  'Moore',
  'Jackson',
  'Martin',
  'Lee',
  'Perez',
  'Thompson',
  'White',
  'Harris',
  'Sanchez',
  'Clark',
  'Ramirez',
  'Lewis',
  'Robinson',
  'Walker',
  'Young',
  'Allen',
  'King',
  'Wright',
  'Scott',
  'Torres',
  'Nguyen',
  'Hill',
  'Flores',
  'Green',
  'Adams',
  'Nelson',
  'Baker',
  'Hall',
  'Rivera',
  'Campbell',
  'Mitchell',
  'Carter',
  'Roberts',
];
const firstNames = [
  'Mary',
  'Patricia',
  'Jennifer',
  'Linda',
  'Elizabeth',
  'Barbara',
  'Susan',
  'Jessica',
  'Sarah',
  'Karen',
  'Nancy',
  'Lisa',
  'Margaret',
  'Betty',
  'Sandra',
  'Ashley',
  'Dorothy',
  'Kimberly',
  'Emily',
  'Donna',
  'Michelle',
  'Carol',
  'Amanda',
  'Melissa',
  'Deborah',
  'Stephanie',
  'Rebecca',
  'Laura',
  'Sharon',
  'Cynthia',
  'Kathleen',
  'Amy',
  'Shirley',
  'Angela',
  'Helen',
  'Anna',
  'Brenda',
  'Pamela',
  'Nicole',
  'Samantha',
  'Katherine',
  'Emma',
  'Ruth',
  'Christine',
  'Catherine',
  'Debra',
  'Rachel',
  'Carolyn',
  'Janet',
  'Virginia',
  'Maria',
  'Heather',
  'Diane',
  'Julie',
  'Joyce',
  'Victoria',
  'Kelly',
  'Christina',
  'Lauren',
  'Joan',
  'Evelyn',
  'Olivia',
  'Judith',
  'Megan',
  'Cheryl',
  'Martha',
  'Andrea',
  'Frances',
  'Hannah',
  'Jacqueline',
  'Ann',
  'Gloria',
  'Jean',
  'Kathryn',
  'Alice',
  'Teresa',
  'Sara',
  'Janice',
  'Doris',
  'Madison',
  'Julia',
  'Grace',
  'Judy',
  'Abigail',
  'Marie',
  'Denise',
  'Beverly',
  'Amber',
  'Theresa',
  'Marilyn',
  'Danielle',
  'Diana',
  'Brittany',
  'Natalie',
  'Sophia',
  'Rose',
  'Isabella',
  'Alexis',
  'Kayla',
  'Charlotte',
  'James',
  'John',
  'Robert',
  'Michael',
  'William',
  'David',
  'Richard',
  'Joseph',
  'Thomas',
  'Charles',
  'Christopher',
  'Daniel',
  'Matthew',
  'Anthony',
  'Donald',
  'Mark',
  'Paul',
  'Steven',
  'Andrew',
  'Kenneth',
  'Joshua',
  'Kevin',
  'Brian',
  'George',
  'Edward',
  'Ronald',
  'Timothy',
  'Jason',
  'Jeffrey',
  'Ryan',
  'Jacob',
  'Gary',
  'Nicholas',
  'Eric',
  'Jonathan',
  'Stephen',
  'Larry',
  'Justin',
  'Scott',
  'Brandon',
  'Benjamin',
  'Samuel',
  'Frank',
  'Gregory',
  'Raymond',
  'Alexander',
  'Patrick',
  'Jack',
  'Dennis',
  'Jerry',
  'Tyler',
  'Aaron',
  'Jose',
  'Henry',
  'Adam',
  'Douglas',
  'Nathan',
  'Peter',
  'Zachary',
  'Kyle',
  'Walter',
  'Harold',
  'Jeremy',
  'Ethan',
  'Carl',
  'Keith',
  'Roger',
  'Gerald',
  'Christian',
  'Terry',
  'Sean',
  'Arthur',
  'Austin',
  'Noah',
  'Lawrence',
  'Jesse',
  'Joe',
  'Bryan',
  'Billy',
  'Jordan',
  'Albert',
  'Dylan',
  'Bruce',
  'Willie',
  'Gabriel',
  'Alan',
  'Juan',
  'Logan',
  'Wayne',
  'Ralph',
  'Roy',
  'Eugene',
  'Randy',
  'Vincent',
  'Russell',
  'Louis',
  'Philip',
  'Bobby',
  'Johnny',
  'Bradley',
];

==> fhir_auth-0.11.0-dev.1.tar.gz: demos/webauthdemo/lib/new_patient.dart <==
import 'dart:math';

import 'package:fhir/r4.dart';

Patient newPatient() {
  final endDigits = digits(6).toString();
  final zNum = digits(4).toString();
  return Patient(
    identifier: [
      Identifier(
        type: CodeableConcept(
          coding: [
            Coding(
              system: FhirUri('http://hl7.org/fhir/sid/us-ssn'),
              code: FhirCode('SB'),
            ),
          ],
        ),
        system: FhirUri('urn:oid:2.16.840.1.113883.4.1'),
        value: digits(9).toString(),
      ),
      // Identifier.fromJson({
      //   "use": "usual",
      //   "type": {"text": "WPRINTERNAL"},
      //   "system": "urn:oid: 1.2.840.114350.1.13.0.1.7.2.${digits(6)}",
      //   "value": "${digits(3)}",
      // }),
      Identifier.fromJson(
        {
          "use": "usual",
          "type": {"text": "EXTERNAL"},
          "system": "urn:oid: 1.2.840.114350.1.13.0.1.7.2.$endDigits",
          "value": "Z$zNum"
        },
      ),
      Identifier.fromJson(
        {
          "use": "usual",
          "type": {"text": "INTERNAL"},
          "system": "urn:oid: 1.2.840.114350.1.13.0.1.7.2.$endDigits",
          "value": "Z$zNum"
        },
      ),
    ],
    active: FhirBoolean(true),
    name: [
      HumanName(
        family: lastNames[random(50)],
        given: [firstNames[random(200)]],
      ),
    ],
    address: [Address(postalCode: zipCode())],
    gender: random(10) < 5 ? FhirCode('male') : FhirCode('female'),
    birthDate: FhirDate(
        '${1900 + random(120)}-0${random(8) + 1}-${(random(27) + 1).toString().padLeft(2, '0')}'),
  );
}

int random(int numb) {
  final _rand = Random();
  return _rand.nextInt(numb);
}

String zipCode() => digits(5);

String digits(int digit) {
  const _chars = '1234567890';
  final _rnd = Random();
  return String.fromCharCodes(Iterable.generate(
      digit, (_) => _chars.codeUnitAt(_rnd.nextInt(_chars.length))));
}

const lastNames = [
  'Smith',
  'Johnson',
  'Williams',
  'Brown',
  'Jones',
  'Garcia',
  'Miller',
  'Davis',
  'Rodriguez',
  'Martinez',
  'Hernandez',
  'Lopez',
  'Gonzalez',
  'Wilson',
  'Anderson',
  'Thomas',
  'Taylor',
  'Moore',
  'Jackson',
  'Martin',
  'Lee',
  'Perez',
  'Thompson',
  'White',
  'Harris',
  'Sanchez',
  'Clark',
  'Ramirez',
  'Lewis',
  'Robinson',
  'Walker',
  'Young',
  'Allen',
  'King',
  'Wright',
  'Scott',
  'Torres',
  'Nguyen',
  'Hill',
  'Flores',
  'Green',
  'Adams',
  'Nelson',
  'Baker',
  'Hall',
  'Rivera',
  'Campbell',
  'Mitchell',
  'Carter',
  'Roberts',
];
const firstNames = [
  'Mary',
  'Patricia',
  'Jennifer',
  'Linda',
  'Elizabeth',
  'Barbara',
  'Susan',
  'Jessica',
  'Sarah',
  'Karen',
  'Nancy',
  'Lisa',
  'Margaret',
  'Betty',
  'Sandra',
  'Ashley',
  'Dorothy',
  'Kimberly',
  'Emily',
  'Donna',
  'Michelle',
  'Carol',
  'Amanda',
  'Melissa',
  'Deborah',
  'Stephanie',
  'Rebecca',
  'Laura',
  'Sharon',
  'Cynthia',
  'Kathleen',
  'Amy',
  'Shirley',
  'Angela',
  'Helen',
  'Anna',
  'Brenda',
  'Pamela',
  'Nicole',
  'Samantha',
  'Katherine',
  'Emma',
  'Ruth',
  'Christine',
  'Catherine',
  'Debra',
  'Rachel',
  'Carolyn',
  'Janet',
  'Virginia',
  'Maria',
  'Heather',
  'Diane',
  'Julie',
  'Joyce',
  'Victoria',
  'Kelly',
  'Christina',
  'Lauren',
  'Joan',
  'Evelyn',
  'Olivia',
  'Judith',
  'Megan',
  'Cheryl',
  'Martha',
  'Andrea',
  'Frances',
  'Hannah',
  'Jacqueline',
  'Ann',
  'Gloria',
  'Jean',
  'Kathryn',
  'Alice',
  'Teresa',
  'Sara',
  'Janice',
  'Doris',
  'Madison',
  'Julia',
  'Grace',
  'Judy',
  'Abigail',
  'Marie',
  'Denise',
  'Beverly',
  'Amber',
  'Theresa',
  'Marilyn',
  'Danielle',
  'Diana',
  'Brittany',
  'Natalie',
  'Sophia',
  'Rose',
  'Isabella',
  'Alexis',
  'Kayla',
  'Charlotte',
  'James',
  'John',
  'Robert',
  'Michael',
  'William',
  'David',
  'Richard',
  'Joseph',
  'Thomas',
  'Charles',
  'Christopher',
  'Daniel',
  'Matthew',
  'Anthony',
  'Donald',
  'Mark',
  'Paul',
  'Steven',
  'Andrew',
  'Kenneth',
  'Joshua',
  'Kevin',
  'Brian',
  'George',
  'Edward',
  'Ronald',
  'Timothy',
  'Jason',
  'Jeffrey',
  'Ryan',
  'Jacob',
  'Gary',
  'Nicholas',
  'Eric',
  'Jonathan',
  'Stephen',
  'Larry',
  'Justin',
  'Scott',
  'Brandon',
  'Benjamin',
  'Samuel',
  'Frank',
  'Gregory',
  'Raymond',
  'Alexander',
  'Patrick',
  'Jack',
  'Dennis',
  'Jerry',
  'Tyler',
  'Aaron',
  'Jose',
  'Henry',
  'Adam',
  'Douglas',
  'Nathan',
  'Peter',
  'Zachary',
  'Kyle',
  'Walter',
  'Harold',
  'Jeremy',
  'Ethan',
  'Carl',
  'Keith',
  'Roger',
  'Gerald',
  'Christian',
  'Terry',
  'Sean',
  'Arthur',
  'Austin',
  'Noah',
  'Lawrence',
  'Jesse',
  'Joe',
  'Bryan',
  'Billy',
  'Jordan',
  'Albert',
  'Dylan',
  'Bruce',
  'Willie',
  'Gabriel',
  'Alan',
  'Juan',
  'Logan',
  'Wayne',
  'Ralph',
  'Roy',
  'Eugene',
  'Randy',
  'Vincent',
  'Russell',
  'Louis',
  'Philip',
  'Bobby',
  'Johnny',
  'Bradley',
];
